import pandas as pd
import os

def checkName(user_query, index=False):
    """
    checkName uses a database lookup to return either SMILES or IUPAC 
    names of salts given either one of those are provided as inputs.
    Default behavior is to return the SMILES encoding of a salt given
    the salt name as input.
    
    Parameters
    ------------------
    user_query : str
        string that will be used to query the database.
        
    Returns
    ------------------
    output: str
        either the name of the salt, cation, or anion; or SMILES of the
        salt, cation, or anion (SMILES for the salt are written as the 
        cation and ion SMILES strings separated by a comma)
    """
    if os.path.isfile('saltInfo.csv') == False:
        print('database file missing... exiting')
        return 0
    df = pd.read_csv('saltInfo.csv').astype(str)

    try:
        target_lookup = df.loc[(df == user_query).any(axis=1),:]
        input_type = df.loc[:,(df == user_query).any(axis=0)].columns.values
        target_column_index = df.columns.get_loc(input_type[0])
        target_row_index = df.loc[(df == user_query).any(axis=1),:].index.tolist()[0]

    except:
        print("query %s not found" % target_lookup)
        return 0
    if target_column_index == 1 or target_column_index == 2 or target_column_index == 3:
        target = target_lookup.iloc[0][target_column_index+3]
    else:
        target = target_lookup.iloc[0][target_column_index-3]
    if index:
        return target, target_row_index
    else:
        return target
